#
# spec file for package zenity
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           zenity
Version:        4.1.90
Release:        1.1
Summary:        GNOME Command Line Dialog Utility
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Projects/Zenity
Source0:        %{name}-%{version}.tar.zst

BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  help2man
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)

%description
Zenity is a basic rewrite of gdialog, without the pain involved of
trying to figure out commandline parsing.  Zenity is zen-like; simple
and easy to use.

Zenity Dialogs: Calendar, Text Entry, Error, Informational, File
Selection, List, Progress, Question, Text Information, Warning and
Password.

Zenity is especially useful in scripts.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%check
%meson_test

%files
%doc AUTHORS ChangeLog NEWS README.md
%license COPYING
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/zenity
%{_mandir}/man?/zenity.?%{ext_man}
%{_datadir}/applications/org.gnome.Zenity.desktop
%{_datadir}/icons/hicolor/48x48/apps/zenity.png

%files lang -f %{name}.lang

%changelog
* Fri Jan 31 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.1.90 (Unstable):
  + forms:
  - Add --add-multiline-entry option for multi-line text entry.
  - Don't free unowned strings.
  - Set hexpand to make more consistent with behaviour of Zenity
    3.x
  + css: Give textviews a border
  + colview: Decrease padding to make more consistent with Zenity
    3.x
  + util: Fix typo in macro
  + Disable AdwMessageDialog deprecation warnings for libadwaita >=
    1.6
  + test updates
  + Updated translations.
* Fri Jan 31 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.0.5:
  + ci: Update .gitlab-ci.yml to automate and deploy new Zenity
    tarballs going forward.
  + forms: set hexpand to make more consistent with behaviour of
    zenity 3.x.
  + Updated translations.
* Thu Oct 31 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Switch to source service for tarball.
* Wed Oct 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.0.3:
  + progress:
  - Support markup on label update STDIN
  - Properly setup custom ok/cancel labels
  + color: Properly support custom ok/cancel labels
  + test: Add test for custom ok/cancel buttons
  + Updated translations.
* Thu Jul  4 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.0.2:
  + tree:
  - Enable 'activates-default' in GtkSearchEntry
  - Don't try to print nonexisting items
  + main: Fix command-line signal signature
  + colview:
  - Return if nth item of row exceeds num items in row
  - Add more sanity checks
  - Clicking on column titles should sort items
  + filesel:
  - Passing a dir with trailing '/' should open that dir
  - Allow a non-existing filename with --save and add associated
    test
  - Remove spurious extra _show() call
  + Updated translations.
* Fri Jan 26 2024 jun wang <jgwang@suse.com>
- Update to version 4.0.1
  + Changes and fixes since 4.0.0:
  - Bump webkit2gtk requirement in README
  - about: The licence is LGPL2.1+, not GPL
  - entry: Calculate number of --entry-text's properly (#75)
  - test: Add entry test in response to issue #75
  - question: fix option --default-cancel
  - calendar: Fix off-by-one in day
  - test: Add test for --calendar
  - Updated translations.
* Fri Dec  8 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 4.0.0:
  + 1st stable release of Zenity based on libadwaita/gtk4.
  + Several command-line options have been deprecated since 3.x.
    These deprecations will either activate an alternate action, or
    do nothing. In either case, a deprecation warning will be
    printed to STDERR. This is to ensure as smooth a transition
    from scripts targeting Zenity 3.x as possible.
  + Changes and bugfixes since 3.99.91:
  - Add rudimentary test suite
  - progress: --auto-close and --percentage=100 don't co-mingle
  - about: Port to libadwaita; update copyright info
  - forms:
    . Remove unused variable
    . Port GtkComboBox to GtkDropDown
  - tree/colview: Implement missing --hide-header option
  - progress: OK should be clickable if --percentage=100 at the
    outset
  - NEWS: fix typo
  - Updated translations.
* Mon Dec  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.99.91:
  + password:
  - Remove spurious "Warning" heading
  - Only fetch username buffer if username option specified
  + build: Add implicit fallthrough warnings
  + password/msg: Handle ZENITY_TIMEOUT to be in line with other
    libadwaita-based dialogs
  + filesel: Fix exit statuses for cancel and timeout
  + Cleanup 'timeout' and make it work properly for all dialogs
  + util: Maintain default timeout exit status as 5 for backwards
    compat; various cleanups
  + text: webkit2gtk-6.0 fixes
  + msg: Code cleanups
  + Updated translations.
* Fri Nov 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.99.90:
  + build: Make building manpage dependent upon manpage option
  + text: Handle long inputs properly
  + colview: Use g_signal_connect_object
  + tree/colview: Return correct value when filtered using search;
    code cleanups
  + colview: Add missing declaration to header
  + build:
  - Make implicit declarations an error
  - Make zenity4 compile against gtk 4.12 without deprecation
    warnings
  + tree:
  - Fix reading input from a named pipe
  - --checklist or --radiolist with < 2 cols should be an error
  - Fix output for non-check/radio multiple selections
  + util: Replace gtk_window_destroy() with
    gtk_application_remove_window().
  + Updated translations.
* Thu Sep  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.99.2:
  + Minor code cleanups
  + option:
  - Don't try to access stack-based argv within a glib2 mainloop
  - Allow --version and --help to work without a display server
    running
  + data: Reinstate help2man manpage autogeneration
  + build: Make manpage/help2man requirement more explicit
  + ci: Add help2man as 'build_fedora' target build dep
  + Updated translations.
* Thu Aug 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.99.1:
  + question: do not hardcode "Yes" and "No" buttons
  + Set the default response explicitly for all AdwMessageDialog's
  + column-view: Widget should go directly in GtkScrolledWindow
  + msg: Make --ok-label and --cancel-label work for --question
    dialogs
  + Add separate case for ZENITY_ESC; don't print junk or crash
    with extra buttons
  + Fix --extra-button and delete events for legacy
    (non-libadwaita) dialogs
  + filesel: Fix --filename for zenity 4.x
  + Updated translations.
- Re-enable help2man BuildRequires, now that no longer fails the
  build.
* Wed Jun  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.99.0:
  + option: Add various non-fatal deprecation warnings that were
    previously missing, and fix a misleading deprecation message
    for `--window-icon`
  + main: Add G_APPLICATION_FLAGS_NON_UNIQUE to GApplication flags
  + progress: Cleanup unnecessary static objects and remove
    spurious builder unref
  + util:
  - Remove fatal assert on exit if window invalid GtkWindow
  - Ignore superfluous quit requests
  - Remove superfluous GtkWindow cast check
  + data: Manpage generation changes; don't automatically generate
    the manpage from help2man for now (this will preferably be
    reinstated post-4.0 once the issues are worked out)
  + a11y: Label the widgets in a forms UI properly
  + Updated translations.
* Thu May  4 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.92.0:
  + progress: don't update responses that aren't there
  + Set dialog 'heading', not 'title' for the --title option
  + tree: fix handling of multi-row stdin input
  + tree-column-view: don't steal children
  + Port to webkitgtk 6.0
  + webkit: Fix leak by removing unnecessary ref sink
  + option: Add non-fatal deprecation warning for
  - -confirm-overwrite
  + help: Fix typo in Basque help translation
  + Updated translations.
* Tue Mar  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.91.0:
  + tree: Port to GtkColumnView
  + desktop file: Remove spurious translation comment
  + i18n: rename POTFILES to POTFILES.in
  + help:
  - Fix invalid markup in German help translation
  - Freedesktop.org spec fixes
  + Updated translations.
* Fri Jan 27 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.90.0:
  + Initial alpha release based on libadwaita and GTK4.
- Replace pkgconfig(gtk+-3.0) with pkgconfig(gtk4) and add
  desktop-file-utils and pkgconfig(libadwaita-1) BuildRequires
  following upstream changes. Also add a check section and
  meson_test macro.
- Add disabled help2man BuildRequires, needed for man pages but
  currently fails the build.
* Fri Jan 27 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.44.0:
  + scale: set a page increment so mouse wheel can be used on
    widget.
  + build:
  - Use GNOME module post_install().
  - Replace deprecated functions.
  + docs: Fix incorrect markup.
  + Updated translations.
* Fri Sep 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pkgconfig(libnotify) and pkgconfig(webkit2gtk-4.1)
  BuildRequires: Upstream disabled building of libnotify and html
  support by default more than a year ago, and we have not been
  building that support in this time, so lets drop the unused
  dependencies.
* Thu Jul  7 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.43.0:
  + Documentation updates.
  + Bump WebkitGTK dependency to API 4.1, for GNOME 43.
  + Updated translations.
- Add pkgconfig(webkit2gtk-4.1) BuildRequires: enable webkit
  support.
* Wed Apr 27 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.42.1:
  + scale: Make OK button default (allows pressing Enter to accept
    selected value).
  + Fix maximum width of message dialogs to 60 characters, and make
    message dialogs non-resizable (fixes regression from 3b64d05e).
* Fri Apr  1 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.42.0:
  + tree: Clicking row checks radio/checkboxes.
  + Fix search column selection with --imagelist.
  + Updated translations.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Mon Aug 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.41.0:
  + Port to meson.
  + Code cleanups.
  + Updated translations.
- Add meson BuildRequires and replace configure/make/make_install
  with meson/meson_build/meson_install macros.
- Drop zenity-Fix-segfault-on-multiple-lists.patch: fixed
  upstream.
* Fri Jan 24 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pkgconfig(webkit2gtk-4.0) BuildRequires and pass
  - -disable-webkitgtk to configure, no longer build webkitgtk
  support.
- Drop zenity-lang Recommends, not needed as -lang supplements
  takes care of it.
* Thu Sep 26 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add zenity-Fix-segfault-on-multiple-lists.patch: src/forms.c: Fix
  segfault on multiple lists without values.
* Fri Mar 22 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Fix autotools warnings.
  + Use upstream autoreconf instead deprecated gnome-autogen.
  + Add <description> to DOAP file.
  + Replace Bugzilla by Gitlab URL in DOAP file.
  + help: Update all screenshots for Zenity 3.30.
- Drop zenity-Makes-progress-consider-decimal.patch: Fixed
  upstream.
* Fri Dec 28 2018 bjorn.lie@gmail.com
- Add upstream bug fix patch:
  + zenity-Makes-progress-consider-decimal.patch: Makes progress to
    consider the decimal from percent update.
* Fri Oct  5 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Updated translations.
* Tue Apr 10 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Mon Mar 12 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec file using spec-cleaner.
* Wed Feb 14 2018 dimstar@opensuse.org
- Use SPDX-3.0 license identifier.
- Package COPYING as %%license, not as %%doc.
* Mon Feb  5 2018 dimstar@opensuse.org
- Drop gettext BuildRequires that was introduced with the 3.26.0
  update: the dependency is not needed.
* Sun Feb  4 2018 luc14n0@linuxmail.org
- Update to version 3.27.90:
  + Updated translations.
* Tue Nov 14 2017 luc14n0@linuxmail.org
- Update to version 3.26.0:
  + Use GtkFileChooserNative for the file chooser.
- Changes from version 3.24.1:
  + Fix:
  - Style.
  - Message dialog width and height on recent Gtk.
  - Misleading indentation.
  + Add clang-format script.
  + Bug 762347: Addition of entry text width option.
  + Updated translations.
- Changes from version 3.24.2:
  + No changes.
- Update Url to https://wiki.gnome.org/Projects/Zenity: current
  Zenity project's web page.
- Point fdupes to the data directory instead of the build root,
  which is a practice that must be avoided.
- Remove %%clean section as it's no longer needed since RPM now does
  the job by itself.
- Replace intltool by gettext BuildRequires: since upstream did the
  migration long ago and we don't want deviations to avoid bugs.
* Tue Mar 21 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Several fixes for proper translations.
  + Updated translations.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Wed Mar 23 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Sat Oct 17 2015 zaitor@opensuse.org
- Update to version 3.18.1.1:
  + Fix compilation when webkitgtk is not installed (bgo#756756).
* Sat Oct 17 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Fixing GLib-CRITICAL messages.
  + Fixing html option being parsed to other dialogs rather then
    text-info.
  + Fixing glade file.
  + Updated translations.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Fix Makefile files.
  + Updated translations.
* Wed Jun 24 2015 zaitor@opensuse.org
- Update to version 3.16.3:
  + Fix zenity --list.
  + bgo#751332: zenity --forms does not center in the screen.
  + bgo#638582: zenity --notification --listen can't show multi
    line tooltip.
  + Add the possibility to pass title and the summary to zenity
    notification.
  + bgo#672090: Impossible to confirm --text-info.
  + bgo#742963: Basic notifications do not return.
  + Fix GLib critical messages.
  + Fixing deprecated declarations.
  + Fix uninitialized progress_bar error.
  + Fix typo in documentation.
  + Port to webkit2gtk.
  + Updated translations.
- Replace pkgconfig(webkitgtk-3.0) for pkgconfig(webkit2gtk-4.0)
  BuildRequires following upstreams port.
* Thu May 14 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + bgo#749359: zenity --list produces incorrect output.
  + Do not make zenity_util_show_dialog() X11 specific.
  + Use upstream gettext instead intltool.
  + Improve some strings.
  + option.c: Fixing typo in extra-button option.
  + Merge branch 'jjardon/no_deprecated'.
  + ADD gchar **extra_label TO struct ZenityData.
  + Allow build if GDK_WINDOWING_X11 not set.
  + Fix bgo#734196.
  + Updated translations.
* Wed May 13 2015 zaitor@opensuse.org
- Update to version 3.16.0:
  + Allow user to interact with --text-info --html WebView.
  + bgo#700249: Progress dialog does not wrap.
  + Better sollution for wrap text.
  + bgo#734049: zenity --text-info chokes on some UTF-8 string.
  + Allow --text-info to load resources also from relative file://
    URIs.
  + bgo#685051: Adding --mid-search option to --list.
  + Fixing g_timeout_add calls.
  + Fixing remain g_timeout_add.
  + Allow --text-info to load resources from absolute file:// URIs.
  + Added time-remaining support to progress bars.
  + Don't quit zenity when the input stream is closed.
  + Updated translations.
* Mon Sep 22 2014 zaitor@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Wed Sep 17 2014 dimstar@opensuse.org
- Add pkgconfig(webkitgtk-3.0) BuildRequires: enable --html output
  features (bnc#896674).
* Mon Sep 15 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Segmentation fault on zenity --notification (bgo#733870).
  + Updated translations.
- Changes from version 3.13.90:
  + Updated translations.
* Tue Apr 29 2014 dimstar@opensuse.org
- Update to version 3.12.1:
  + User docs: Make page ID the same as file name.
  + Updated FSF's address.
  + Add user help for --listen (bgo#711396).
  + Man page points to nonexisting doc (bgo#667711).
  + zenity --text-info should have an auto scroll option
    (bgo#600533).
  + Need ability to specify default answer in --question dialog
    (bgo#534935).
  + List box doesn't expand to fill window (bgo#702535).
  + Updated translations.
* Tue Dec 10 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#854638):
  + List box doesn't expand to fill window (bgo#702535).
- Changes from version 3.10.1:
  + Updated translations.
- Changes from version 3.9.91:
  + Add a runtime check for X11 (bgo#705335).
  + Fix the broken auto-close option in progress and list dialogs
    (bgo#653468).
  + Double clicking an item or hitting enter after selecting an
    item returns it twice (bgo#698683).
* Tue Mar 26 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Timeout option overriding normal exit code (bgo#674881)
  + Replaced string 'could' to start with an Uppercase (bgo#687180)
  + Updated translatons.
* Sat Nov 24 2012 dimstar@opensuse.org
- Update to version 3.7.2:
  + Updated translations.
* Wed Sep 26 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Add an option to set a custom dialog icon (bgo#684329)
  + Add an option to request dialogs being modal (bgo#684322)
  + Port to new documentation infrastructure
  + Fix the ComboBoxText construction so the dropmenu works
  + Fix various compiler warnings
  + Added support to --imagelist on tree
  + Do not crash in --forms --add-list without column values
    (bgo#676406)
  + Now the --pulsate option works properly (bgo#567663)
  + Fix segmentation fault in --list option (bgo#673529)
  + Updated translations.
- Drop zenity-add-sentinel.patch: fixed upstream.
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstreams port to the new documentation infrastructure.
- No longer pass --disable-scrollkeeper to configure: it's no
  longer a known parameter after the port to yelp-tools.
- Remove conditions for end-of-life openSUSE versions.
* Sun Mar 25 2012 dimstar@opensuse.org
- Update to version 3.4.0:
  + Add support for lists and trees with --forms.
  + zenity --list from stdin gives bogus "Invalid file descriptor"
    warning (bgo#668935).
  + Updated translations.
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Updated translations.
* Wed Aug 17 2011 dimstar@opensuse.org
- Update to version 3.1.5:
  + Enable html support in --text-info option.
  + Add --ok-label and --cancel-label in all dialogs.
  + Documentation / man page updates.
  + Bugs fixed: bgo#611297, bgo#592199, bgo#598655, bgo#540489,
    bgo#501001, bgo#621907, bgo#651948, bgo#651723.
  + Updated translations.
- Add zenity-add-sentinel.patch: Add sentinel to g_object_get
  function call.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Updated translations.
* Tue Feb 22 2011 fcrozat@novell.com
- Update to version 2.91.90:
  + Various bug fixes.
  + Updated translations.
- Changes from version 2.91.5:
  + Add font and no wrap mode support in text dialog.
  + Fix for bgo#540560.
  + Updated translations.
* Sun Feb 13 2011 vuntz@opensuse.org
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Fri Dec 17 2010 vuntz@opensuse.org
- Update to version 2.91.1.1:
  + Remove deprecated code for GTK+-3.0.
  + Fix manpage for the statusicon removal from Zenity 3.0.
  + Updated translations.
- Changes from version 2.91.1:
  + Make zenity compile only with GTK+-3.0.
  + Add default activation on entry for password dialog.
  + Updated translations.
- Move to pkgconfig()-style BuildRequires:
  + Old ones: gtk2-devel, libnotify-devel.
  + New ones: glib-2.0, gtk+-3.0, libnotify.
* Tue Nov 16 2010 dimstar@opensuse.org
- Update to version 2.32.1:
  + Add default activation on entry for password dialog.
  + Updated translations.
* Tue Sep 28 2010 lmedinas@opensuse.org
- Update to version 2.32.0:
  + Updated translations.
* Tue Sep 14 2010 vuntz@opensuse.org
- Update to version 2.31.92:
  + Updated translations.
* Thu Aug  5 2010 vuntz@opensuse.org
- Update to version 2.31.6:
  + Make zenity compile with GTK2 and GTK3
  + bgo#624612: update zenity help file
  + Removing X_LIBS from src/Makefile
  + Change cancel button messages to be capitalized
  + Updated translations.
- Build against GTK+ 2 again: use gtk2-devel BuildRequires instead
  of gtk3-devel.
* Tue Jul 27 2010 dimstar@opensuse.org
- Update to version 2.31.5:
  + bgo#616816: Add new entries to Zenity's man page
  + Add new password dialog
  + In order to build with GTK 3.0, change
    GTK_DIALOG(dialog)->vbox to gtk_dialog_get_content_area()
  + Add password.c to be translated
  + Bump to 2.31.5 and use GTK+ 3.0
- Changes from version 2.31.3:
  + Use g_timeout_add_seconds instead g_timeout_add.
  + Updated translations.
- Use gtk3-devel BuildRequires instead of gtk2-devel.
* Wed Jul  7 2010 dimstar@opensuse.org
- Update to version 2.31.3:
  + Use g_timeout_add_seconds instead g_timeout_add
  + Updated translations.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + Updated documentation and translations.
- Remove en@shaw translations on 11.2 and earlier.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated documentation and translations.
* Thu Aug 13 2009 dominique-obs@leuenberger.net
- Replace libglade2-devel BuildRequires with gtk2-devel.
* Tue Aug 11 2009 captain.magnus@opensuse.org
- Update to version 2.27.90:
  + Convert from libglade to GtkBuilder [bgo#578393]
  + zenity windows don't appear with the focus
    [bgo#561131]
  + "zenity --entry --text" doesn't interpret line breaks
    [bgo#567773]
  + zenity sets a huge but finite timeout [bgo#579999]
  + Explicitly link against libX11 [bgo#559638]
  + --help-entry for hide-text incorrect [bgo#549404]
  + Fix default activation in entry dialog [bgo#551116]
  + Help manual fixes/additions
  + Misc code cleanups/improvements
  + Translation updates
* Tue Mar 17 2009 mboman@suse.de
- Update to version 2.26.0:
  * disable monk easter egg in order to remove gnome-canvas
    dependency [bgo#571741]
  * replace deprecated GTK+ calls [bgo#571869]
  * remove deprecated/obsoleted dialog definition
    [bgo#571869]
  + Translation updates
- Don't package %%{_datadir}/omf/zenity in main package
- Remove docbook-xsl-stylesheets, gnome-doc-utils,
  libgnomecanvas-devel, perl-XML-Parser and scrollkeeper from
  BuildRequires
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Thu Jan 29 2009 lmedinas@gmail.com
- Update to version 2.24.1:
  + Document --timeout
  + correctly handle --filename on file selection dialog
  + Cleanup GLib and GTK+ includes
  + Remove deprecated GLib symbols
  + Translator comments
  + Updated translations
* Wed Jan 28 2009 vuntz@novell.com
- Own /usr/share/gnome/help to not depend on libgnome.
* Tue Sep 23 2008 maw@suse.de
- Update to version 2.24.0:
  + Updated translations.
* Mon Jun 23 2008 maw@suse.de
- Update to version 2.23.3.1:
  + Bugs fixed: bgo#529452, bgo#409843, bgo#526627, bgo#527258,
    bgo#335763, bgo#516876, bgo#521574, and bgo#520847
  + Updated translations.
* Fri Apr 11 2008 vuntz@suse.de
- Update to version 2.22.1:
  + Updated translations.
* Tue Mar 11 2008 vuntz@suse.de
- Update to version 2.22.0:
  + Updated documentation translations.
  + Updated translations.
* Wed Mar  5 2008 maw@suse.de
- Update to version 2.21.1:
  + Updated documentation
  + Updated translations.
* Thu Dec 20 2007 jpr@suse.de
- Update to version 2.20.1:
  + Updated translations.
-Enable libnotify support
* Tue Sep 18 2007 maw@suse.de
- Update to version 2.20.0:
  + Updated translations.
* Fri Aug 31 2007 maw@suse.de
- Update tov ersion 2.19.2:
  + Bugs (bugzilla.gnome.org) fixed: #160654, #453713, #343684,
    [#407275], and #410055
  + Updated translations.
* Tue Aug  7 2007 maw@suse.de
- Use %%fdupes
- Split off a -lang subpackage.
* Thu Jul 12 2007 mauro@suse.de
- Update to 2.19.1
- Bugfixes for #405006, #420396, #436187.
* Fri Apr 27 2007 sbrabec@suse.cz
- Do not call meinproc (#227624).
* Wed Apr 11 2007 maw@suse.de
- Update to version 2.18.1 which includes new translations.
* Sat Mar 31 2007 jpr@suse.de
- Update to version 2.18.0
  * Translations
* Fri Mar  9 2007 maw@suse.de
- Update to version 2.17.91.
  * New and updated translations
  * Don't show cancel button on warning dialogs (Claudio Saavedra)
    [#324100]
  * Don't kill parent process by default when canceling progress dialog.
    New option --auto-kill added to activate this behavior (Diego Urrelo)
    [#310824]
  * Small i18n fixes (Lucas Rocha) [334361]
  * Make dialog text selectable on message dialogs (Greg Hudson) [352910]
  * Fix list dialog options (Glynn Foster) [#353320]
* Thu Jan  4 2007 sbrabec@suse.cz
- Spec file cleanup.
* Mon Dec 18 2006 maw@suse.de
- Move to /usr.
* Fri Dec  8 2006 dmueller@suse.de
- don't build as root
* Sat Oct 14 2006 danw@suse.de
- Remove dead patches
* Thu Oct 12 2006 ro@suse.de
- added gnome-doc-utils-devel to buildreq
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 2.16.1
- translation updates
* Thu Sep 14 2006 jhargadon@suse.de
- update to version 2.16.0
- New and updated translations
* Tue Aug 29 2006 jhargadon@suse.de
- update to version 2.15.92
- translation updates
- About dialog update
- Text entry activation makes dialog return
- Correctly handle stdin input on text info dialog
- Port notification to GtkStatusIcon
- New dropdown menu on entry dialog
- Implementation of "message" command on notification
  which pops notification bubbles
- New --confirm-overwrite to file selection dialog to
  pop confirmation dialog when selection an existing
  filename
- Quit zenity on about dialog response
- Manpage fixes
- Small memory allocation fixes
- Remove xlibs dependency
- Fix list dialog separator option
* Mon Aug 28 2006 ro@suse.de
- disable scrollkeeper parts
* Thu Jul 20 2006 danw@suse.de
- Fix a bug exposed in autobuild by the glib2 update (already
  fixed upstream)
* Fri Mar 10 2006 danw@suse.de
- Make the "zenity --notification" tray icon transparent. 155345
* Tue Feb 28 2006 sbrabec@suse.cz
- Use kdelibs3-doc in BuildRequires for meinproc (#153635#c14).
* Mon Feb 27 2006 aj@suse.de
- Readd kdelibs3-devel for meinproc.
* Sat Feb 25 2006 aj@suse.de
- Reduce BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct 13 2005 gekker@suse.de
- Update to version 2.12.1
* Tue Sep  6 2005 aj@suse.de
- Update to 2.12.0 (GNOME 2.12).
* Tue Aug 23 2005 gekker@suse.de
- Update to version 2.11.92
* Thu Aug 11 2005 gekker@suse.de
- Update to version 2.11.91
* Tue Aug  2 2005 gekker@suse.de
- Update to version 2.11.90
* Fri Jul 22 2005 gekker@suse.de
- Update to 2.11.0
* Thu Mar 10 2005 gekker@suse.de
- Update to version 2.10.0 (GNOME 2.10).
* Thu Mar  3 2005 gekker@suse.de
- update to version 2.9.92
* Fri Feb 11 2005 gekker@suse.de
- Update to versions 2.9.91
- Remove upstreamed patch
* Sat Jan 22 2005 ro@suse.de
- fix build on lib64
* Thu Jan 20 2005 clahey@suse.de
- Updated to version 2.9.2.
* Tue Oct 26 2004 mmj@suse.de
- locale rename no to nb
* Fri Aug 27 2004 clahey@suse.de
- Cache zenity help and show zenity in khelpcenter.
* Mon May 10 2004 sbrabec@suse.cz
- Updated to version 2.6.2 (GNOME 2.6).
* Mon Mar 15 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Thu Feb 19 2004 sbrabec@suse.cz
- Updated to version 1.8.
* Mon Feb  9 2004 hhetter@suse.de
- updated to version 1.7 [GNOME2.4.2]
* Thu Oct  9 2003 sbrabec@suse.cz
- Added new SuSE package, version 1.6 (GNOME 2.4).
